==> ejc-lz-impl-3.0.0-20220509.024412-92-sources.jar: com/ejianc/business/base/vo/SupplierinfoVO.java <==
package com.ejianc.business.base.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 供应商基本信息
 * 
 * @author generator
 * 
 */
public class SupplierinfoVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String code; // 供应商编码
    private Long manageId; // 管理ID
    private String supplyName; // 供应商名称
    private Long categoryId; // 分类id
    private String categoryName; // 分类名称
    private Long orgId; // 组织id
    private String orgName; // 组织名称
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private Long changeId; // 变更单据id
    private String changeState; // 变更状态，1:未变更;2:变更中;3:已变更
    private String manageName; // 供应商管理档案名称
    private String legalPerson; // 法人
    private String businessLicense; // 营业执照号
    private String address; // 地址
    private String remark; // 备注
    private String orgCode; // 组织机构代码证号
    private String payCondition; // 付款条件
    private BigDecimal creditLimit; // 赊销额度
    private Integer creditDate; // 赊销期
    private BigDecimal minPrice; // 最低价
    private String calculateMethod; // 计算方式:1 入库开始算 2 验收开始算
    private Integer hideFlag; // 隐藏标志:0 显示 1 隐藏
    private String errorMsg; // 错误信息

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    @ReferSerialTransfer(referCode="SuppliermanageRef")
    public Long getManageId() {
        return manageId;
    }
    @ReferDeserialTransfer
    public void setManageId(Long manageId) {
        this.manageId = manageId;
    }
    public String getSupplyName() {
        return supplyName;
    }

    public void setSupplyName(String supplyName) {
        this.supplyName = supplyName;
    }
    @ReferSerialTransfer(referCode="SuppliercategoryRef")
    public Long getCategoryId() {
        return categoryId;
    }

    @ReferDeserialTransfer
    public void setCategoryId(Long categoryId) {
        this.categoryId = categoryId;
    }
    public String getCategoryName() {
        return categoryName;
    }

    public void setCategoryName(String categoryName) {
        this.categoryName = categoryName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    public String getChangeState() {
        return changeState;
    }

    public void setChangeState(String changeState) {
        this.changeState = changeState;
    }

    public String getManageName() {
        return manageName;
    }

    public void setManageName(String manageName) {
        this.manageName = manageName;
    }
    @ReferSerialTransfer(referCode="idm-org")
    public Long getOrgId() {
        return orgId;
    }
    @ReferDeserialTransfer
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public String getLegalPerson() {
        return legalPerson;
    }

    public void setLegalPerson(String legalPerson) {
        this.legalPerson = legalPerson;
    }

    public String getBusinessLicense() {
        return businessLicense;
    }

    public void setBusinessLicense(String businessLicense) {
        this.businessLicense = businessLicense;
    }

    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public String getPayCondition() {
        return payCondition;
    }

    public void setPayCondition(String payCondition) {
        this.payCondition = payCondition;
    }

    public BigDecimal getCreditLimit() {
        return creditLimit;
    }

    public void setCreditLimit(BigDecimal creditLimit) {
        this.creditLimit = creditLimit;
    }

    public Integer getCreditDate() {
        return creditDate;
    }

    public void setCreditDate(Integer creditDate) {
        this.creditDate = creditDate;
    }

    public BigDecimal getMinPrice() {
        return minPrice;
    }

    public void setMinPrice(BigDecimal minPrice) {
        this.minPrice = minPrice;
    }

    public String getCalculateMethod() {
        return calculateMethod;
    }

    public void setCalculateMethod(String calculateMethod) {
        this.calculateMethod = calculateMethod;
    }

    public Integer getHideFlag() {
        return hideFlag;
    }

    public void setHideFlag(Integer hideFlag) {
        this.hideFlag = hideFlag;
    }

    public String getErrorMsg() {
        return errorMsg;
    }

    public void setErrorMsg(String errorMsg) {
        this.errorMsg = errorMsg;
    }
}

==> ejc-lz-impl-3.0.0-20220526.021003-106-sources.jar: com/ejianc/business/base/vo/SupplierinfoVO.java <==
package com.ejianc.business.base.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 供应商基本信息
 * 
 * @author generator
 * 
 */
public class SupplierinfoVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String code; // 供应商编码
    private Long manageId; // 管理ID
    private String supplyName; // 供应商名称

    private Long categoryId; // 分类id
    private String categoryName; // 分类名称
    private BigDecimal cleanFare; // 清理费
    private Long orgId; // 组织id
    private String orgName; // 组织名称
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private Long changeId; // 变更单据id
    private String changeState; // 变更状态，1:未变更;2:变更中;3:已变更
    private String manageName; // 供应商管理档案名称
    private String legalPerson; // 法人
    private String businessLicense; // 营业执照号
    private String address; // 地址
    private String remark; // 备注
    private String orgCode; // 组织机构代码证号
    private String payCondition; // 付款条件
    private BigDecimal creditLimit; // 赊销额度
    private Integer creditDate; // 赊销期
    private BigDecimal minPrice; // 最低价
    private String calculateMethod; // 计算方式:1 入库开始算 2 验收开始算
    private Integer hideFlag; // 隐藏标志:0 显示 1 隐藏
    private String errorMsg; // 错误信息
    private String linkerName; // 联系人名称
    private String linkerPhone; // 联系人电话
    private String bankName; // 银行名称
    private String bankAccount; // 银行账户
    private String bankPerson; // 银行开户名
    private String controlName; // 实际控制人名称
    private String controlPhone; // 控制人名称

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    @ReferSerialTransfer(referCode="SuppliermanageRef")
    public Long getManageId() {
        return manageId;
    }
    @ReferDeserialTransfer
    public void setManageId(Long manageId) {
        this.manageId = manageId;
    }
    public String getSupplyName() {
        return supplyName;
    }

    public void setSupplyName(String supplyName) {
        this.supplyName = supplyName;
    }
    @ReferSerialTransfer(referCode="SuppliercategoryRef")
    public Long getCategoryId() {
        return categoryId;
    }

    @ReferDeserialTransfer
    public void setCategoryId(Long categoryId) {
        this.categoryId = categoryId;
    }
    public String getCategoryName() {
        return categoryName;
    }

    public void setCategoryName(String categoryName) {
        this.categoryName = categoryName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    public String getChangeState() {
        return changeState;
    }

    public void setChangeState(String changeState) {
        this.changeState = changeState;
    }

    public String getManageName() {
        return manageName;
    }

    public void setManageName(String manageName) {
        this.manageName = manageName;
    }
    @ReferSerialTransfer(referCode="idm-org")
    public Long getOrgId() {
        return orgId;
    }
    @ReferDeserialTransfer
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public String getLegalPerson() {
        return legalPerson;
    }

    public void setLegalPerson(String legalPerson) {
        this.legalPerson = legalPerson;
    }

    public String getBusinessLicense() {
        return businessLicense;
    }

    public void setBusinessLicense(String businessLicense) {
        this.businessLicense = businessLicense;
    }

    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public String getPayCondition() {
        return payCondition;
    }

    public void setPayCondition(String payCondition) {
        this.payCondition = payCondition;
    }

    public BigDecimal getCreditLimit() {
        return creditLimit;
    }

    public void setCreditLimit(BigDecimal creditLimit) {
        this.creditLimit = creditLimit;
    }

    public Integer getCreditDate() {
        return creditDate;
    }

    public void setCreditDate(Integer creditDate) {
        this.creditDate = creditDate;
    }

    public BigDecimal getMinPrice() {
        return minPrice;
    }

    public void setMinPrice(BigDecimal minPrice) {
        this.minPrice = minPrice;
    }

    public String getCalculateMethod() {
        return calculateMethod;
    }

    public void setCalculateMethod(String calculateMethod) {
        this.calculateMethod = calculateMethod;
    }

    public Integer getHideFlag() {
        return hideFlag;
    }

    public void setHideFlag(Integer hideFlag) {
        this.hideFlag = hideFlag;
    }

    public String getErrorMsg() {
        return errorMsg;
    }

    public void setErrorMsg(String errorMsg) {
        this.errorMsg = errorMsg;
    }

    public BigDecimal getCleanFare() {
        return cleanFare;
    }

    public void setCleanFare(BigDecimal cleanFare) {
        this.cleanFare = cleanFare;
    }

    public String getLinkerName() {
        return linkerName;
    }

    public void setLinkerName(String linkerName) {
        this.linkerName = linkerName;
    }

    public String getLinkerPhone() {
        return linkerPhone;
    }

    public void setLinkerPhone(String linkerPhone) {
        this.linkerPhone = linkerPhone;
    }

    public String getBankName() {
        return bankName;
    }

    public void setBankName(String bankName) {
        this.bankName = bankName;
    }

    public String getBankAccount() {
        return bankAccount;
    }

    public void setBankAccount(String bankAccount) {
        this.bankAccount = bankAccount;
    }

    public String getBankPerson() {
        return bankPerson;
    }

    public void setBankPerson(String bankPerson) {
        this.bankPerson = bankPerson;
    }

    public String getControlName() {
        return controlName;
    }

    public void setControlName(String controlName) {
        this.controlName = controlName;
    }

    public String getControlPhone() {
        return controlPhone;
    }

    public void setControlPhone(String controlPhone) {
        this.controlPhone = controlPhone;
    }
}
